@@ -1,5 +1,8 @@
+import datetime
+
 from collections import OrderedDict
 
+
 def group_activities(queryset):
     """
     Given a queryset of activity objects, will group them by actors and return an OrderedDict including:
@@ -14,13 +17,18 @@ def group_activities(queryset):
     """
     actions = OrderedDict()
     for item in queryset:
+        if item.timestamp >= datetime.date.today():
+            current_item = True
+        else:
+            current_item = False
         if item.target not in actions.keys():
             actions[item.target] = {
                 'item': item,
                 'actors': [item.actor_name],
                 'actor_count': 0,
                 'verb': item.override_string if item.override_string else item.verb,
-                'last_modified': item.timestamp
+                'last_modified': item.timestamp,
+                'current_item': current_item
             }
         else: # item was previously added, but we need to update attributes
             if item.actor_name not in actions[item.target]['actors']:
@@ -28,5 +36,5 @@ def group_activities(queryset):
                 actions[item.target]['actor_count'] += 1
             if actions[item.target]['last_modified'] < item.timestamp:
                 actions[item.target]['last_modified'] = item.timestamp
-    
+
     return actions
